package eu.jonahbauer.wizard.client.libgdx.screens;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Screen;
import com.badlogic.gdx.audio.Music;
import com.badlogic.gdx.audio.Sound;
import com.badlogic.gdx.graphics.GL20;
import com.badlogic.gdx.graphics.Pixmap;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.scenes.scene2d.InputEvent;
import com.badlogic.gdx.scenes.scene2d.InputListener;
import com.badlogic.gdx.scenes.scene2d.Stage;
import com.badlogic.gdx.scenes.scene2d.ui.Skin;
import com.badlogic.gdx.scenes.scene2d.ui.Table;
import com.badlogic.gdx.scenes.scene2d.ui.TextButton;
import com.badlogic.gdx.utils.viewport.ScreenViewport;
import eu.jonahbauer.wizard.client.libgdx.WizardGame;

public class MainMenuScreen implements Screen {

    public static Music backgroundSound = Gdx.audio.newMusic(Gdx.files.internal("background.wav"));
    public static Sound buttonClickSound = Gdx.audio.newSound(Gdx.files.internal("button_click_s.mp3"));

    Pixmap pm;

    Texture background;
    Texture topLeft;
    Texture topRight;
    Texture bottomLeft;
    Texture bottomRight;
    Texture wizard;
    Texture leftSymbol;
    Texture middleSymbol;
    Texture rightSymbol;

    TextButton chooseServerButton;
    TextButton exitButton;

    Skin skin;
    Stage stage;
    public WizardGame game;

    public MainMenuScreen(WizardGame game) {
        this.game = game;
    }

    @Override
    public void show() {
        pm = new Pixmap(Gdx.files.internal("cursor.png"));
        Gdx.graphics.setCursor(Gdx.graphics.newCursor(pm, 0, 0));
        pm.dispose();

        backgroundSound.setLooping(true);
        backgroundSound.setVolume(0.07f);
        backgroundSound.play();
        skin = new Skin(Gdx.files.internal("skin/uiskin.json"));
        stage = new Stage(new ScreenViewport());

        background = new Texture(Gdx.files.internal("background.png"));
        leftSymbol = new Texture(Gdx.files.internal("symbol3.png"));
        middleSymbol = new Texture(Gdx.files.internal("symbol1.png"));
        rightSymbol = new Texture(Gdx.files.internal("symbol2.png"));

        topLeft = new Texture(Gdx.files.internal("ecke_lo.png"));
        topRight = new Texture(Gdx.files.internal("ecke_ro.png"));
        bottomLeft = new Texture(Gdx.files.internal("ecke_lu.png"));
        bottomRight = new Texture(Gdx.files.internal("ecke_ru.png"));

        wizard = new Texture(Gdx.files.internal("schriftzug.png"));

        chooseServerButton = new TextButton("Spiel beitreten", skin);
        chooseServerButton.setPosition((WizardGame.WIDTH / 2f) - (chooseServerButton.getWidth() / 2f), WizardGame.HEIGHT * 0.35f);
        exitButton = new TextButton("Verlassen", skin);
        exitButton.setPosition(WizardGame.WIDTH / 2f - exitButton.getWidth() / 2f, chooseServerButton.getY() - WizardGame.HEIGHT * 0.1f);

        Gdx.input.setInputProcessor(stage);
        stage.addActor(chooseServerButton);
        stage.addActor(exitButton);

        chooseServerButton.addListener(new InputListener() {
            @Override
            public boolean touchDown(InputEvent event, float x, float y, int pointer, int button) {
                buttonClickSound.play(0.6f);
                game.setScreen(new ServerScreen(game));
                return true;
            }
        });

        exitButton.addListener(new InputListener() {
            @Override
            public boolean touchDown(InputEvent event, float x, float y, int pointer, int button) {
                buttonClickSound.play(0.6f);
                try {
                    Thread.sleep(450);
                } catch (InterruptedException e) {
                    //e.printStackTrace();
                }
                Gdx.app.exit();
                return true;
            }
        });
    }

    @Override
    public void render(float delta) {

        Gdx.gl.glClear(GL20.GL_COLOR_BUFFER_BIT);
        stage.act(Gdx.graphics.getDeltaTime());
        this.game.batch.begin();
        this.game.batch.draw(background, 0, 0);
        this.game.batch.draw(topLeft, 0, WizardGame.HEIGHT - topLeft.getHeight());
        this.game.batch.draw(topRight, WizardGame.WIDTH - topRight.getWidth(), WizardGame.HEIGHT - topRight.getHeight());
        this.game.batch.draw(bottomLeft, 0, 0);
        this.game.batch.draw(bottomRight, WizardGame.WIDTH - bottomRight.getWidth(), 0);
        this.game.batch.draw(wizard, (WizardGame.WIDTH / 2f) - (wizard.getWidth() / 2f), WizardGame.HEIGHT * 0.73f);
        this.game.batch.draw(leftSymbol, WizardGame.WIDTH * 0.32f, WizardGame.HEIGHT * 0.45f);
        this.game.batch.draw(middleSymbol, WizardGame.WIDTH / 2f - middleSymbol.getWidth() / 2f, WizardGame.HEIGHT * 0.49f);
        this.game.batch.draw(rightSymbol, WizardGame.WIDTH * 0.68f - rightSymbol.getWidth(), WizardGame.HEIGHT * 0.45f);
        this.game.batch.end();
        stage.draw();

    }

    @Override
    public void resize(int width, int height) {

    }

    @Override
    public void pause() {

    }

    @Override
    public void resume() {

    }

    @Override
    public void hide() {

    }

    @Override
    public void dispose() {
    }
}
