package eu.jonahbauer.wizard.client.libgdx.screens;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Screen;
import com.badlogic.gdx.graphics.GL20;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.scenes.scene2d.Group;
import com.badlogic.gdx.scenes.scene2d.InputEvent;
import com.badlogic.gdx.scenes.scene2d.InputListener;
import com.badlogic.gdx.scenes.scene2d.Stage;
import com.badlogic.gdx.scenes.scene2d.ui.Skin;
import com.badlogic.gdx.scenes.scene2d.ui.TextButton;
import com.badlogic.gdx.scenes.scene2d.ui.TextField;
import com.badlogic.gdx.utils.viewport.ScreenViewport;
import eu.jonahbauer.wizard.client.libgdx.WizardGame;

public class ServerScreen implements Screen {

    Texture background;
    Texture topLeft;
    Texture topRight;
    Texture bottomLeft;
    Texture bottomRight;
    Texture wizard;

    TextButton backButton;
    TextButton continueButton;

    TextField ip;
    TextField port;
    TextField playerName;

    Group inputs;

    Skin skin;
    Stage stage;
    public WizardGame game;

    public ServerScreen(WizardGame game) {
        this.game = game;
    }

    @Override
    public void show() {
        skin = new Skin(Gdx.files.internal("skin/uiskin.json"));
        stage = new Stage(new ScreenViewport());

        background = new Texture(Gdx.files.internal("background.png"));

        topLeft = new Texture(Gdx.files.internal("ecke_lo.png"));
        topRight = new Texture(Gdx.files.internal("ecke_ro.png"));
        bottomLeft = new Texture(Gdx.files.internal("ecke_lu.png"));
        bottomRight = new Texture(Gdx.files.internal("ecke_ru.png"));

        wizard = new Texture(Gdx.files.internal("schriftzug_s.png"));

        backButton = new TextButton("Zurück", skin);
        backButton.setPosition(WizardGame.WIDTH * 0.3f, WizardGame.HEIGHT * 0.18f);
        backButton.setSize(120, backButton.getHeight());
        continueButton = new TextButton("Fortfahren", skin);
        continueButton.setPosition(WizardGame.WIDTH * 0.7f - continueButton.getWidth(), WizardGame.HEIGHT * 0.18f);

        inputs = new Group();
        inputs.setSize(300, continueButton.getHeight());
        inputs.setPosition(WizardGame.WIDTH / 2f - inputs.getWidth() / 2, WizardGame.HEIGHT * 0.5f);

        ip = new TextField("", skin);
        //ip.setPosition(WizardGame.WIDTH*0.4f, WizardGame.HEIGHT*0.5f);
        ip.setSize(200, continueButton.getHeight());
        port = new TextField("", skin);
        port.setPosition(ip.getX() + ip.getWidth() + WizardGame.WIDTH * 0.005f, ip.getY());
        port.setSize(80, continueButton.getHeight());
        playerName = new TextField("", skin);
        playerName.setSize(250, continueButton.getHeight());
        playerName.setPosition(WizardGame.WIDTH / 2f - playerName.getWidth() / 2, inputs.getY() - WizardGame.HEIGHT * 0.12f);

        inputs.addActor(ip);
        inputs.addActor(port);

        Gdx.input.setInputProcessor(stage);
        stage.addActor(backButton);
        stage.addActor(continueButton);
        stage.addActor(playerName);
        stage.addActor(inputs);
        //stage.addActor(port);

        backButton.addListener(new InputListener() {
            @Override
            public boolean touchDown(InputEvent event, float x, float y, int pointer, int button) {
                MainMenuScreen.buttonClickSound.play(0.6f);
                game.setScreen(new MainMenuScreen(game));
                return true;
            }
        });

        continueButton.addListener(new InputListener() {
            @Override
            public boolean touchDown(InputEvent event, float x, float y, int pointer, int button) {
                MainMenuScreen.buttonClickSound.play(0.6f);
                game.setScreen(new SessionListScreen(game));
                return true;
            }
        });

    }

    @Override
    public void render(float delta) {
        Gdx.gl.glClear(GL20.GL_COLOR_BUFFER_BIT);
        stage.act(Gdx.graphics.getDeltaTime());
        this.game.batch.begin();
        this.game.batch.draw(background, 0, 0);
        this.game.batch.draw(topLeft, 0, WizardGame.HEIGHT - topLeft.getHeight());
        this.game.batch.draw(topRight, WizardGame.WIDTH - topRight.getWidth(), WizardGame.HEIGHT - topRight.getHeight());
        this.game.batch.draw(bottomLeft, 0, 0);
        this.game.batch.draw(bottomRight, WizardGame.WIDTH - bottomRight.getWidth(), 0);
        this.game.batch.draw(wizard, (WizardGame.WIDTH / 2f) - (wizard.getWidth() / 2f), WizardGame.HEIGHT * 0.75f);
        this.game.batch.end();
        stage.draw();
    }

    @Override
    public void resize(int width, int height) {

    }

    @Override
    public void pause() {

    }

    @Override
    public void resume() {

    }

    @Override
    public void hide() {

    }

    @Override
    public void dispose() {

    }
}
